@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Acme::CPANModules;
 
 our $DATE = '2018-01-09'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -61,12 +61,11 @@ sub weave_section {
 
     my $filename = $input->{filename};
 
-    my $package;
-    if ($filename =~ m!^lib/(.+)\.pm$!) {
-        $package = $1;
-        $package =~ s!/!::!g;
-        $self->_process_module($document, $input, $package);
-    }
+    return unless $filename =~ m!^lib/(.+)\.pm$!;
+    my $package = $1;
+    $package =~ s!/!::!g;
+    return unless $package =~ /\AAcme::CPANModules::/;
+    $self->_process_module($document, $input, $package);
 }
 
 1;
@@ -84,7 +83,7 @@ Pod::Weaver::Plugin::Acme::CPANModules - Plugin to use when building Acme::CPANM
 
 =head1 VERSION
 
-This document describes version 0.001 of Pod::Weaver::Plugin::Acme::CPANModules (from Perl distribution Pod-Weaver-Plugin-Acme-CPANModules), released on 2018-01-09.
+This document describes version 0.002 of Pod::Weaver::Plugin::Acme::CPANModules (from Perl distribution Pod-Weaver-Plugin-Acme-CPANModules), released on 2018-01-09.
 
 =head1 SYNOPSIS
 
